==> haskell-xcffib-0.8.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcffib
version: 0.8.1
id: xcffib-0.8.1-2L2padafNRqEltLrsUoPlg
key: xcffib-0.8.1-2L2padafNRqEltLrsUoPlg
license: LicenseRef-OtherLicense
maintainer: Tycho Andersen <tycho@tycho.ws>
author: Tycho Andersen
homepage: http://github.com/tych0/xcffib
synopsis: A cffi-based python binding for X
description:
    A cffi-based python binding for X, comparable to xpyb
category: X11
abi: 4f452ddad08228405acf2995edda729d
exposed: True
exposed-modules:
    Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
import-dirs: /usr/lib/ghc-8.6.5/site-local/xcffib-0.8.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/xcffib-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/xcffib-0.8.1
hs-libraries: HSxcffib-0.8.1-2L2padafNRqEltLrsUoPlg
depends:
    attoparsec-0.13.2.2-EdUct2wsQri8X0bjC24wTV base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    either-5.0.1.1-K2xF2YPbWUOAi0qhET6TQx
    filemanip-0.3.6.3-4gIDkmoap4z2kDIgJy5hH filepath-1.4.2.1
    language-python-0.5.6-AkoEmDTtd2QJdCwGLwBOuT mtl-2.2.2
    split-0.2.3.3-4dhvbosBVIlDAhhwnzSbSM
    xcb-types-0.10.0-LAPkEAFk1M02nxYyKVKkJ0
haddock-interfaces: /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html: /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcffib-0.8.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcffib
version: 0.8.1
id: xcffib-0.8.1-K7vgSzAWlQVDLRyaIdOzRH
key: xcffib-0.8.1-K7vgSzAWlQVDLRyaIdOzRH
license: LicenseRef-OtherLicense
maintainer: Tycho Andersen <tycho@tycho.ws>
author: Tycho Andersen
homepage: http://github.com/tych0/xcffib
synopsis: A cffi-based python binding for X
description:
    A cffi-based python binding for X, comparable to xpyb
category: X11
abi: 688f6d0a65663b37dded738320213433
exposed: True
exposed-modules:
    Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
import-dirs: /usr/lib/ghc-8.6.5/site-local/xcffib-0.8.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/xcffib-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/xcffib-0.8.1
hs-libraries: HSxcffib-0.8.1-K7vgSzAWlQVDLRyaIdOzRH
depends:
    attoparsec-0.13.2.2-4cHpHFFBuyN5UF0oDRVEML base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    either-5.0.1.1-EqVXiClQOygBMrkElqWc1
    filemanip-0.3.6.3-4gIDkmoap4z2kDIgJy5hH filepath-1.4.2.1
    language-python-0.5.6-AkoEmDTtd2QJdCwGLwBOuT mtl-2.2.2
    split-0.2.3.3-4dhvbosBVIlDAhhwnzSbSM
    xcb-types-0.10.0-LAPkEAFk1M02nxYyKVKkJ0
haddock-interfaces: /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html: /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
